Call class

Call object represents a call going on with the users device

Constructors

Call({required String uuid, required String address, required bool outgoing, required CallState callState})

Properties

address → String
address or handle of the call
final
callState ↔ CallState
current state of call
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
muted ↔ bool
getter/setter pair
outgoing → bool
outgoing is true if call is initiated by the user
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid → String
UUID of call
final

Methods

copyWith({String? uuid, String? address, bool? outgoing, CallState? callState}) → Call
end() → Future<bool>
End the call initiated by the user
hold({bool onHold = true}) → Future<bool>
hold the call initiated by the user
mute({bool muted = true}) → Future<bool>
mute the call initiated by the user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override