CallManager class

internal class. keeps track of all active calls. Should not be accessed outside of plugin

Constructors

CallManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCall(Call call) → void
Adds a call and notifies listeners
endAll() → void
Ends all calls
getCallByUuid(String uuid) → Call?
retrievs a call by its UUID if it exists in the current calls
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCall(Call call) → void
removes a call and notifies listeners
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

callListStreamController → StreamController<List<Call>>
Stream that emits when a new call is added or removed
final